MCPcopy Create free account
hub / github.com/ComputationalRobotics/XM-code / transpose

Function transpose

XM/include/Dense/transpose.h:18–22  ·  view source on GitHub ↗

Source from the content-addressed store, hash-verified

16// transpose a matrix
17template <typename T>
18void transpose(T* out, const T* in, size_s width, size_s height) {
19 dim3 blockDim(32, 32);
20 dim3 gridDim((width + blockDim.x - 1) / blockDim.x, (height + blockDim.y - 1) / blockDim.y);
21 transposeKernel<<<gridDim, blockDim>>>(out, in, width, height);
22}
23
24template <typename T>
25__global__ void symKernel(T* out, const T* in, int mat_size) {

Callers 1

XMtrustregionFunction · 0.85

Calls

no outgoing calls

Tested by

no test coverage detected